@@ -3,7 +3,7 @@ package CPAN::Plugin::Sysdeps::Mapping;
 use strict;
 use warnings;
 
-our $VERSION = '0.27';
+our $VERSION = '0.28';
 
 # shortcuts
 #  os and distros
@@ -1486,6 +1486,15 @@ sub mapping {
        [package => 'keyutils-libs-devel']],
      ],
 
+     [cpanmod => 'Lab::VISA',
+      # no package for freebsd
+      [like_debian,
+       [linuxdistrocodename => [qw(jessie xenial)],
+	[package => 'libvisa-dev']],
+       [package => []], # not available anymore in stretch
+      ],
+     ],
+
      # XXX needs verification; maybe more latex-related modules should be listed here?
      [cpanmod => ['LaTeX::Driver', 'Template::Plugin::Latex'],
       [os_freebsd,
@@ -2086,6 +2095,8 @@ sub mapping {
        [package => 'libpcre2-dev']],
       [like_fedora,
        [package => 'pcre2-devel']],
+      [os_darwin,
+       [package => 'pcre2']],
      ],
 
      [cpanmod => 'Remind::Client', # but does not work: "Remind output didn't look right; got: 2017/04/24 it works! today"
